=== modified file 'jujupy.py'
--- jujupy.py	2016-11-15 19:55:20 +0000
+++ jujupy.py	2016-11-15 22:34:10 +0000
@@ -608,8 +608,7 @@
     def __init__(self, status_name, item_name, item_value):
         self.status_name = status_name
         self.item_name = item_name
-        # (self.item_name, item_value) = item
-        self.status = item_value[status_name]
+        self.status = item_value.get(status_name, item_value)
 
     @property
     def message(self):
@@ -627,7 +626,10 @@
     def version(self):
         return self.status.get('version')
 
+    @property
     def datetime_since(self):
+        if self.since is None:
+            return None
         return datetime.strptime(self.since, '%d %b %Y %H:%M:%SZ')
 
     def to_exception(self):
@@ -643,7 +645,7 @@
         elif self.WORKLOAD == self.status_name:
             if self.message is None:
                 return UnitError(self.item_name, self.message)
-            elif re.match('hook failed ".*install.*"', self.message):
+            elif re.match('hook failed: ".*install.*"', self.message):
                 return InstallError(self.item_name, self.message)
             elif re.match('hook failed', self.message):
                 return HookFailedError(self.item_name, self.message)
@@ -652,7 +654,7 @@
         elif self.MACHINE == self.status_name:
             return MachineError(self.item_name, self.message)
         elif self.JUJU == self.status_name:
-            time_since = datetime.utcnow() - self.datetime_since()
+            time_since = datetime.utcnow() - self.datetime_since
             if time_since > timedelta(minutes=5):
                 return AgentUnresolvedError(self.item_name, self.message,
                                             time_since.total_seconds())

=== modified file 'tests/test_jujupy.py'
--- tests/test_jujupy.py	2016-11-15 19:55:20 +0000
+++ tests/test_jujupy.py	2016-11-15 22:34:10 +0000
@@ -33,6 +33,8 @@
     NoSuchEnvironment,
     )
 from jujupy import (
+    AgentError,
+    AgentUnresolvedError,
     AppError,
     BootstrapMismatch,
     CannotConnectEnv,
@@ -51,7 +53,9 @@
     get_local_root,
     get_machine_dns_name,
     get_timeout_path,
+    HookFailedError,
     IncompatibleConfigClass,
+    InstallError,
     jes_home_path,
     JESNotSupported,
     Juju2Backend,
@@ -67,8 +71,8 @@
     SoftDeadlineExceeded,
     Status,
     Status1X,
+    StatusError,
     StatusItem,
-    StatusError,
     SYSTEM,
     temp_bootstrap_env,
     _temp_env as temp_env,
@@ -5372,6 +5376,72 @@
         self.assertLess(UnitError.priority(), AppError.priority())
 
 
+class TestStatusItem(TestCase):
+
+    @staticmethod
+    def make_status_item(status_name, item_name, **kwargs):
+        return StatusItem(status_name, item_name, {status_name: kwargs})
+
+    def assertIsType(self, obj, target_type):
+        self.assertIs(type(obj), target_type)
+
+    def test_datetime_since(self):
+        item = self.make_status_item(StatusItem.JUJU, '0',
+                                     since='19 Aug 2016 05:36:42Z')
+        target = datetime(2016, 8, 19, 5, 36, 42)
+        self.assertEqual(item.datetime_since, target)
+
+    def test_datetime_since_none(self):
+        item = self.make_status_item(StatusItem.JUJU, '0')
+        self.assertIsNone(item.datetime_since)
+
+    def test_to_exception_good(self):
+        item = self.make_status_item(StatusItem.JUJU, '0', current='idle')
+        self.assertIsNone(item.to_exception())
+
+    def test_to_exception_machine_error(self):
+        item = self.make_status_item(StatusItem.MACHINE, '0', current='error')
+        self.assertIsType(item.to_exception(), MachineError)
+
+    def test_to_exception_app_error(self):
+        item = self.make_status_item(StatusItem.APPLICATION, '0',
+                                     current='error')
+        self.assertIsType(item.to_exception(), AppError)
+
+    def test_to_exception_unit_error(self):
+        item = self.make_status_item(StatusItem.WORKLOAD, 'fake/0',
+                                     current='error',
+                                     message='generic unit error')
+        self.assertIsType(item.to_exception(), UnitError)
+
+    def test_to_exception_hook_failed_error(self):
+        item = self.make_status_item(StatusItem.WORKLOAD, 'fake/0',
+                                     current='error',
+                                     message='hook failed: "bad hook"')
+        self.assertIsType(item.to_exception(), HookFailedError)
+
+    def test_to_exception_install_error(self):
+        item = self.make_status_item(StatusItem.WORKLOAD, 'fake/0',
+                                     current='error',
+                                     message='hook failed: "install error"')
+        self.assertIsType(item.to_exception(), InstallError)
+
+    def make_agent_item_ago(self, minutes):
+        now = datetime.utcnow()
+        then = now - timedelta(minutes=minutes)
+        then_str = then.strftime('%d %b %Y %H:%M:%SZ')
+        return self.make_status_item(StatusItem.JUJU, '0', current='error',
+                                     message='some error', since=then_str)
+
+    def test_to_exception_agent_error(self):
+        item = self.make_agent_item_ago(minutes=3)
+        self.assertIsType(item.to_exception(), AgentError)
+
+    def test_to_exception_agent_unresolved_error(self):
+        item = self.make_agent_item_ago(minutes=6)
+        self.assertIsType(item.to_exception(), AgentUnresolvedError)
+
+
 class TestStatus(FakeHomeTestCase):
 
     def test_iter_machines_no_containers(self):
@@ -6060,21 +6130,6 @@
         self.assertEqual({'service': {}}, status.get_applications())
 
 
-class TestStatusItem(TestCase):
-
-    @staticmethod
-    def make_status_item(status_name, item_name, **kwargs):
-        return StatusItem(status_name, item_name, {status_name: kwargs})
-
-    def test_datetime_since(self):
-        item = self.make_status_item(StatusItem.JUJU, '0',
-                                     since='19 Aug 2016 05:36:42Z')
-        target = datetime(2016, 8, 19, 5, 36, 42)
-        self.assertEqual(item.datetime_since(), target)
-
-    # to_exception is going to need a lot of tests.
-
-
 def fast_timeout(count):
     if False:
         yield

